// *************************************************************************************
// SCICHART® Copyright SciChart Ltd. 2011-2018. All rights reserved.
//  
// Web: http://www.scichart.com
//   Support: support@scichart.com
//   Sales:   sales@scichart.com
// 
// CreateAScatter3DChart.xaml.cs is part of the SCICHART® Examples. Permission is hereby granted
// to modify, create derivative works, distribute and publish any part of this source
// code whether for commercial, private or personal use. 
// 
// The SCICHART® examples are distributed in the hope that they will be useful, but
// without any warranty. It is provided "AS IS" without warranty of any kind, either
// expressed or implied. 
// *************************************************************************************

using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using SciChart.Charting3D.Model;
using SciChart.Charting3D.PointMarkers;
using SciChart.Examples.ExternalDependencies.Data;
using Microsoft.Win32;
using SciChart.Charting.Visuals;

namespace SciChart.Examples.Examples.Charts3D.CreateA3DChart
{
    public partial class CreateAScatter3DChart : UserControl
    {
        public Int64 TotalCount { get; set; }

        public CreateAScatter3DChart()
        {
            SciChartSurface.SetRuntimeLicenseKey(@"
            <LicenseContract>
                  <Customer>sagar.gorla@dwpractice.net</Customer>
                  <OrderId>TRIAL-EXTENSION</OrderId>
                   <LicenseCount>1</LicenseCount>
                   <IsTrialLicense>true</IsTrialLicense>
                   <SupportExpires>12/06/2019 00:00:00</SupportExpires>
                   <KeyCode>tgIBATSKyn3LlNUBAIBHGsir1QEeAAEAaABDdXN0b21lcj1zYWdhci5nb3JsYUBkd3ByYWN0aWNlLm5ldDtPcmRlcklkPVRSSUFMLUVYVEVOU0lPTjtTdWJzY3JpcHRpb25WYWxpZFRvPTA2LURlYy0yMDE5O1Byb2R1Y3RDb2RlPV2FoPauxmoXkh7mU7Ff+jIgpkNiLXuGvQNj49RhLnaOIpbQdsmzYZsdTRoOAR1WJg==</KeyCode>
            </LicenseContract>
              "
         );
            InitializeComponent();

            PointMarkerCombo.Items.Add(typeof(SpherePointMarker3D));
            PointMarkerCombo.Items.Add(typeof(CubePointMarker3D));
            PointMarkerCombo.Items.Add(typeof(PyramidPointMarker3D));
            PointMarkerCombo.Items.Add(typeof(CylinderPointMarker3D));

         


            Loaded += OnLoaded;
        }
        
        private void OnLoaded(object sender, RoutedEventArgs routedEventArgs)
        {
            TotalCount = 100000;// Hundred Thousand Points
            var xyzDataSeries3D = new XyzDataSeries3D<DateTime,double,double>();

            for (var i = 0; i < TotalCount; i++)
            {
                var y = DataManager.Instance.GetGaussianRandomNumber(5, 1.5);
                var z = DataManager.Instance.GetGaussianRandomNumber(5, 1.5);

                xyzDataSeries3D.Append(DateTime.Now.AddHours(i), y, z);
            }

            ScatterSeries3D.DataSeries = xyzDataSeries3D;

            PointMarkerCombo.SelectedIndex = 0;
        }

        private void PointMarkerCombo_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (ScatterSeries3D != null && OpacitySlider != null && SizeSlider != null)
            {
                ScatterSeries3D.PointMarker = (BasePointMarker3D)Activator.CreateInstance((Type)((ComboBox)sender).SelectedItem);
                ScatterSeries3D.PointMarker.Fill = Colors.DeepSkyBlue;
                ScatterSeries3D.PointMarker.Size = (float)SizeSlider.Value;
                ScatterSeries3D.PointMarker.Opacity = OpacitySlider.Value;
            }
        }

        private void SizeSlider_OnValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (ScatterSeries3D != null && ScatterSeries3D.PointMarker != null)
                ScatterSeries3D.PointMarker.Size = (float)((Slider)sender).Value;
        }

        private void OpacitySlider_OnValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (ScatterSeries3D != null && ScatterSeries3D.PointMarker != null)
                ScatterSeries3D.PointMarker.Opacity = ((Slider)sender).Value;
        }
    }
}